Index: trunk/magic/remove/src/diffedpixels.c
===================================================================
--- trunk/magic/remove/src/warpedpixels.c	(revision 25082)
+++ trunk/magic/remove/src/diffedpixels.c	(revision 26438)
@@ -9,6 +9,8 @@
 static int xRight(psPlane *pt, int y);
 
+// Examine the set of diff skycells and compute the pixels that were
+// included in difference processing
 bool
-computeWarpedPixels(streakFiles *sf)
+computeDiffedPixels(streakFiles *sf)
 {
     bool status;
@@ -29,6 +31,6 @@
     psFree(bounds);
 
-    sf->warpedPixels = psImageAlloc(width, height, PS_TYPE_U8);
-    psImageInit(sf->warpedPixels, 0);
+    sf->diffedPixels = psImageAlloc(width, height, PS_TYPE_U8);
+    psImageInit(sf->diffedPixels, 0);
 
     for (int i=0; i<n; i++) {
@@ -42,12 +44,12 @@
     bool writeTouchedPixels = false; // XXX: make this an argument to the program
     if (writeTouchedPixels) {
         // write out the warped pixels
         psMetadata * header = psMetadataAlloc();
         if (sf->inAstrom->fpa->toSky->type != PS_PROJ_DIS) {
             pmAstromWriteWCS(header, sf->inAstrom->fpa, sf->chip, 0.001);
         }
-        psFits *fits = psFitsOpen("warpedpixels.fits", "w");
-
-        psFitsWriteImage(fits, header, sf->warpedPixels, 0, NULL);
+        psFits *fits = psFitsOpen("diffedpixels.fits", "w");
+
+        psFitsWriteImage(fits, header, sf->diffedPixels, 0, NULL);
         psFitsClose(fits);
         psFree(header);
@@ -84,5 +86,5 @@
     /* now set up our wrapper to the chip astrometry to apply to the whole chip */
     sf->astrom = streakSetAstrometry(sf->astrom, sf->stage, sf->inAstrom->fpa, sf->chip, false, NULL,
-        sf->warpedPixels->numCols, sf->warpedPixels->numRows);
+        sf->diffedPixels->numCols, sf->diffedPixels->numRows);
 
     // convert corners of skycell to sky coordinates
@@ -138,5 +140,5 @@
     // Now set the touched pixels
     int ymin = fmax(0, pt[1].y );
-    int ymax = fmin(pt[3].y + 0.5, sf->warpedPixels->numRows - 1);
+    int ymax = fmin(pt[3].y + 0.5, sf->diffedPixels->numRows - 1);
 #if (DEBUG_PRINT > 1)
     printf("\nymin: %d ymax: %d\n", ymin, ymax);
@@ -149,5 +151,5 @@
             xleft = 0;
         }
-        if (xleft > sf->warpedPixels->numCols) {
+        if (xleft > sf->diffedPixels->numCols) {
             continue;
         }
@@ -155,6 +157,6 @@
             continue;
         }
-        if (xright >= sf->warpedPixels->numCols) {
-            xright = sf->warpedPixels->numCols - 1;
+        if (xright >= sf->diffedPixels->numCols) {
+            xright = sf->diffedPixels->numCols - 1;
         }
 #if (DEBUG_PRINT > 1)
@@ -162,5 +164,5 @@
 #endif
 
-        psU8 *rowPixels = sf->warpedPixels->data.U8[y];
+        psU8 *rowPixels = sf->diffedPixels->data.U8[y];
 
         int n = xright - xleft + 1;
@@ -42,12 +44,12 @@
     bool writeTouchedPixels = false; // XXX: make this an argument to the program
     if (writeTouchedPixels) {
-        // write out the warped pixels
+        // write out the diffed pixels
         psMetadata * header = psMetadataAlloc();
         if (sf->inAstrom->fpa->toSky->type != PS_PROJ_DIS) {
